]> git.sesse.net Git - x264/blobdiff - x264.h
Add ability to signal to x264 when speedcontrol buffering is complete
[x264] / x264.h
diff --git a/x264.h b/x264.h
index fd5c0f7a9372317a31e141f4d41f57cbaf7759b8..ccff7c368c9736af81aeeca22d4b0711f5ff7e6d 100644 (file)
--- a/x264.h
+++ b/x264.h
@@ -462,7 +462,8 @@ typedef struct x264_param_t
         float       f_speed;        /* ratio from realtime */
         int         i_buffer_size;  /* number of frames */
         float       f_buffer_init;  /* fraction of size */
-        int         b_alt_timer;    /* use a different method of measuring encode time FIXME */
+        int         b_alt_timer;    /* use a different method of measuring encode time */
+        int         max_preset;     /* maximum speedcontrol preset to use */
     } sc;
 
     /* Muxing parameters */
@@ -963,7 +964,7 @@ int x264_encoder_invalidate_reference( x264_t *, int64_t pts );
 
 /* x264_speedcontrol_sync:
  *      override speedcontrol's internal clock */
-void    x264_speedcontrol_sync( x264_t *, float f_buffer_fill, int i_buffer_size );
+void    x264_speedcontrol_sync( x264_t *, float f_buffer_fill, int i_buffer_size, int buffer_complete );
 
 #ifdef __cplusplus
 }